==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/GroupIcons/AwsStepFunction.md <==
# AwsStepFunction


```text
aws-20210730/Resource/GroupIcons/AwsStepFunction
```

```text
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')
```



| Illustration | AwsStepFunction | AwsStepFunctionCard | AwsStepFunctionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GroupIcons/AwsStepFunction.png) | ![illustration for AwsStepFunction](../../../aws-20210730/Resource/GroupIcons/AwsStepFunction.Local.png) | ![illustration for AwsStepFunctionCard](../../../aws-20210730/Resource/GroupIcons/AwsStepFunctionCard.Local.png) | ![illustration for AwsStepFunctionGroup](../../../aws-20210730/Resource/GroupIcons/AwsStepFunctionGroup.Local.png) |




## AwsStepFunction

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunction
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunction('AwsStepFunction', 'Aws Step Function', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunction
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunction('AwsStepFunction', 'Aws Step Function', 'an optional tech label')
@enduml
```

## AwsStepFunctionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionCard
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionCard('AwsStepFunctionCard', 'Aws Step Function Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionCard
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionCard('AwsStepFunctionCard', 'Aws Step Function Card', 'an optional description')
@enduml
```

## AwsStepFunctionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionGroup
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionGroup('AwsStepFunctionGroup', 'Aws Step Function Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionGroup
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionGroup('AwsStepFunctionGroup', 'Aws Step Function Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/GroupIcons/AwsStepFunction.md <==
# AwsStepFunction


```text
aws-20210730/Resource/GroupIcons/AwsStepFunction
```

```text
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')
```



| Illustration | AwsStepFunction | AwsStepFunctionCard | AwsStepFunctionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GroupIcons/AwsStepFunction.png) | ![illustration for AwsStepFunction](../../../aws-20210730/Resource/GroupIcons/AwsStepFunction.Local.png) | ![illustration for AwsStepFunctionCard](../../../aws-20210730/Resource/GroupIcons/AwsStepFunctionCard.Local.png) | ![illustration for AwsStepFunctionGroup](../../../aws-20210730/Resource/GroupIcons/AwsStepFunctionGroup.Local.png) |




## AwsStepFunction

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunction
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunction('AwsStepFunction', 'Aws Step Function', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunction
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunction('AwsStepFunction', 'Aws Step Function', 'an optional tech label')
@enduml
```

## AwsStepFunctionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionCard
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionCard('AwsStepFunctionCard', 'Aws Step Function Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionCard
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionCard('AwsStepFunctionCard', 'Aws Step Function Card', 'an optional description')
@enduml
```

## AwsStepFunctionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionGroup
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionGroup('AwsStepFunctionGroup', 'Aws Step Function Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStepFunctionGroup
include('aws-20210730/Resource/GroupIcons/AwsStepFunction')

' renders the element
AwsStepFunctionGroup('AwsStepFunctionGroup', 'Aws Step Function Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
